import iam = require('@aws-cdk/aws-iam');
import cdk = require('@aws-cdk/cdk');
/**
 * An SSM Parameter reference.
 */
export interface IParameter extends cdk.IConstruct {
    /**
     * The ARN of the SSM Parameter resource.
     */
    readonly parameterArn: string;
    /**
     * The name of the SSM Parameter resource.
     */
    readonly parameterName: string;
    /**
     * The type of the SSM Parameter resource.
     */
    readonly parameterType: string;
    /**
     * Grants read (DescribeParameter, GetParameter, GetParameterHistory) permissions on the SSM Parameter.
     *
     * @param grantee the role to be granted read-only access to the parameter.
     */
    grantRead(grantee: iam.IPrincipal): void;
    /**
     * Grants write (PutParameter) permissions on the SSM Parameter.
     *
     * @param grantee the role to be granted write access to the parameter.
     */
    grantWrite(grantee: iam.IPrincipal): void;
}
/**
 * A String SSM Parameter.
 */
export interface IStringParameter extends IParameter {
    /**
     * The parameter value. Value must not nest another parameter. Do not use {{}} in the value.
     */
    readonly stringValue: string;
}
/**
 * A StringList SSM Parameter.
 */
export interface IStringListParameter extends IParameter {
    /**
     * The parameter value. Value must not nest another parameter. Do not use {{}} in the value. Values in the array
     * cannot contain commas (``,``).
     */
    readonly stringListValue: string[];
}
/**
 * Properties needed to create a new SSM Parameter.
 */
export interface ParameterProps {
    /**
     * A regular expression used to validate the parameter value. For example, for String types with values restricted to
     * numbers, you can specify the following: ``^\d+$``
     *
     * @default no validation is performed
     */
    readonly allowedPattern?: string;
    /**
     * Information about the parameter that you want to add to the system.
     *
     * @default none
     */
    readonly description?: string;
    /**
     * The name of the parameter.
     *
     * @default a name will be generated by CloudFormation
     */
    readonly name?: string;
}
/**
 * Properties needed to create a String SSM parameter.
 */
export interface StringParameterProps extends ParameterProps {
    /**
     * The value of the parameter. It may not reference another parameter and ``{{}}`` cannot be used in the value.
     */
    readonly stringValue: string;
}
/**
 * Properties needed to create a StringList SSM Parameter
 */
export interface StringListParameterProps extends ParameterProps {
    /**
     * The values of the parameter. It may not reference another parameter and ``{{}}`` cannot be used in the value.
     */
    readonly stringListValue: string[];
}
/**
 * Basic features shared across all types of SSM Parameters.
 */
export declare abstract class ParameterBase extends cdk.Construct implements IParameter {
    abstract readonly parameterName: string;
    abstract readonly parameterType: string;
    constructor(scope: cdk.Construct, id: string, _props: ParameterProps);
    readonly parameterArn: string;
    grantRead(grantee: iam.IPrincipal): void;
    grantWrite(grantee: iam.IPrincipal): void;
}
/**
 * Creates a new String SSM Parameter.
 */
export declare class StringParameter extends ParameterBase implements IStringParameter {
    readonly parameterName: string;
    readonly parameterType: string;
    readonly stringValue: string;
    constructor(scope: cdk.Construct, id: string, props: StringParameterProps);
}
/**
 * Creates a new StringList SSM Parameter.
 */
export declare class StringListParameter extends ParameterBase implements IStringListParameter {
    readonly parameterName: string;
    readonly parameterType: string;
    readonly stringListValue: string[];
    constructor(scope: cdk.Construct, id: string, props: StringListParameterProps);
}
